@@ -10,11 +10,12 @@ from product import *
 def register():
     Pool.register(
         OrderPoint,
+        LocationLeadTime,
         Configuration,
+        ConfigurationSupplyPeriod,
         Production,
-        CreateProductionRequestStart,
         Product,
         module='stock_supply_production', type_='model')
     Pool.register(
-        CreateProductionRequest,
+        StockSupply,
         module='stock_supply_production', type_='wizard')
